@@ -3,7 +3,7 @@
  * Author: Igor Vlasenko <vlasenko@imath.kiev.ua>
  * Created: Fri Jul  1 20:11:51 2005
  *
- * $Id: pstring.c,v 1.13 2006/01/22 19:57:02 igor Exp $
+ * $Id$
  */
 
 #include <stdio.h>
@@ -27,6 +27,14 @@ PSTRING lowercase_pstring (PSTRING pstring) {
   return retval;
 }
 
+void lowercase_pstring_inplace (PSTRING pstring) {
+  char* i=pstring.begin;
+  while (i<pstring.endnext) {
+    *i=tolower(*i);
+    i++;
+  }
+}
+
 int is_pstring_true (PSTRING s) {
   if (s.begin == NULL || s.begin == s.endnext) return 0;
   if (1==s.endnext-s.begin) {
